@@ -1,20 +1,20 @@
 /*************************************************************************************
  *  Copyright (C) 2012 by Alejandro Fiestas Olivares <afiestas@kde.org>              *
- *  Copyright (C) 2012 by Dan Vrátil <dvratil@redhat.com>                            *
+ *  Copyright (C) 2012, 2013 by Daniel Vrátil <dvratil@redhat.com>                   *
  *                                                                                   *
- *  This program is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU General Public License                      *
- *  as published by the Free Software Foundation; either version 2                   *
- *  of the License, or (at your option) any later version.                           *
+ *  This library is free software; you can redistribute it and/or                    *
+ *  modify it under the terms of the GNU Lesser General Public                       *
+ *  License as published by the Free Software Foundation; either                     *
+ *  version 2.1 of the License, or (at your option) any later version.               *
  *                                                                                   *
- *  This program is distributed in the hope that it will be useful,                  *
+ *  This library is distributed in the hope that it will be useful,                  *
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
- *  GNU General Public License for more details.                                     *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
+ *  Lesser General Public License for more details.                                  *
  *                                                                                   *
- *  You should have received a copy of the GNU General Public License                *
- *  along with this program; if not, write to the Free Software                      *
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
+ *  You should have received a copy of the GNU Lesser General Public                 *
+ *  License along with this library; if not, write to the Free Software              *
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
  *************************************************************************************/
 
 #ifndef XRANDR_BACKEND_H
@@ -24,8 +24,9 @@
 #include "../abstractbackend.h"
 
 #include <QtCore/QSize>
+#include <QLoggingCategory>
 
-class XRandRX11Helper;
+class XRandRXCBHelper;
 class XRandRConfig;
 namespace KScreen {
     class Output;
@@ -35,6 +36,7 @@ class XRandR : public QObject, public AbstractBackend
 {
     Q_OBJECT
     Q_INTERFACES(AbstractBackend)
+    Q_PLUGIN_METADATA(IID "org.kf5.kscreen.backends.xrandr")
 
     public:
         explicit XRandR(QObject* parent = 0);
@@ -59,6 +61,7 @@ class XRandR : public QObject, public AbstractBackend
 
     private Q_SLOTS:
         void updateConfig();
+        void outputRemovedSlot();
 
         void updateOutput(RROutput output);
         void updateCrtc(RRCrtc crtc);
@@ -76,9 +79,9 @@ class XRandR : public QObject, public AbstractBackend
         static bool s_has_1_3;
         static bool s_xorgCacheInitialized;
 
-        XRandRX11Helper *m_x11Helper;
+        XRandRXCBHelper *m_x11Helper;
         bool m_isValid;
 };
 
-extern int dXndr();
+Q_DECLARE_LOGGING_CATEGORY(KSCREEN_XRANDR)
 #endif //XRandR_BACKEND_H
